import sys
import requests
import json
import re

# Set the path to your yt-dlp Instagram cookies file
yt_dlp_cookie_file = "/home/arslantste/public_html/inst_down/instagram_cookies.txt"

# Load cookies from file
def load_cookies_from_file(cookie_file):
    cookies = {}
    try:
        with open(cookie_file, "r") as file:
            for line in file:
                if not line.startswith("#") and line.strip():
                    parts = line.strip().split("\t")
                    if len(parts) >= 7:
                        cookies[parts[5]] = parts[6]  # Cookie name and value
    except Exception as e:
        return {"error": f"Failed to load cookies: {str(e)}"}

    return cookies

# Extract image from Instagram meta tags
def extract_image_from_meta_tags(post_url, cookies):
    headers = {
        "User-Agent": "Mozilla/5.0",
        "Referer": "https://www.instagram.com/",
    }

    try:
        response = requests.get(post_url, headers=headers, cookies=cookies)
        
        # Debugging: Print raw response
        print(json.dumps({
            "status_code": response.status_code,
            "headers": dict(response.headers),
            "raw_response": response.text[:1000]  # Print first 1000 characters
        }, indent=4))

        if response.status_code != 200:
            return {"error": f"Failed to fetch page, status code: {response.status_code}"}

        # Try extracting meta tag data
        meta_match = re.search(r'<meta property="og:image" content="(https://[^"]+)"', response.text)
        if meta_match:
            return {"image_url": meta_match.group(1)}

        return {"error": "Image URL not found in meta tags"}

    except Exception as e:
        return {"error": f"Request failed: {str(e)}"}

# Main function to download Instagram image
def download_instagram_image(post_url):
    cookies = load_cookies_from_file(yt_dlp_cookie_file)
    if "error" in cookies:
        return cookies

    return extract_image_from_meta_tags(post_url, cookies)

# Run the script
if __name__ == "__main__":
    if len(sys.argv) > 1:
        post_url = sys.argv[1]
        result = download_instagram_image(post_url)
        print(json.dumps(result, indent=4))
    else:
        print(json.dumps({"error": "No URL provided"}))
